import { Plugin } from 'prosemirror-state';
import { type CoreEditor } from './CoreEditor.js';
import { InputRule } from './plugins/input-rules/InputRulesPlugin.js';
import { Commands, CommandShortcuts } from './commands/mod.js';
import { Schema, type SchemaSpec } from 'prosemirror-model';
export interface ExtensionConfig {
    [key: string]: any;
    requires: Array<Extension | string>;
}
export interface Converter {
    fromDoc(document: unknown): void;
    toDoc(content: unknown): any;
}
export declare abstract class Extension {
    protected config: Partial<ExtensionConfig>;
    readonly type = "extension";
    abstract name: string;
    protected constructor(config?: Partial<ExtensionConfig>);
    getInputRules(): InputRule[];
    getProseMirrorPlugins(editor: CoreEditor, schema: Schema): Plugin[];
    getCommands(editor: CoreEditor): Partial<Commands>;
    getKeyboardShortcuts(): Partial<CommandShortcuts>;
    getConverters(): Record<string, Converter>;
    setupSpec(spec: SchemaSpec): void;
}
//# sourceMappingURL=Extension.d.ts.map