import { createChainableState } from './createChainableState.js';
export class CommandManager {
    constructor(editor, rawCommands = {}) {
        Object.defineProperty(this, "editor", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: editor
        });
        Object.defineProperty(this, "rawCommands", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: rawCommands
        });
    }
    get state() {
        return this.editor.state;
    }
    get chain() {
        return () => this.createChain();
    }
    get can() {
        return () => this.createCan();
    }
    createChain(startTr, shouldDispatch = true) {
        const { rawCommands, editor, state } = this;
        const { view } = editor;
        const callbacks = [];
        const hasStartTransaction = !!startTr;
        const tr = startTr || state.tr;
        const chainedState = createChainableState(tr, state);
        const fakeDispatch = () => undefined;
        const chain = {
            ...Object.fromEntries(Object.entries(rawCommands).map(([name, command]) => {
                const chainedCommand = (...args) => {
                    const callback = command(...args)(chainedState, shouldDispatch ? fakeDispatch : undefined);
                    callbacks.push(callback);
                    return chain;
                };
                return [name, chainedCommand];
            })),
            run: () => {
                if (!hasStartTransaction &&
                    shouldDispatch &&
                    !tr.getMeta('preventDispatch')) {
                    view.dispatch(tr);
                }
                return callbacks.every((callback) => callback === true);
            },
            chain: () => {
                return this.createChain(tr, shouldDispatch);
            },
        };
        return chain;
    }
    createCan(startTr) {
        return this.createChain(startTr, false);
    }
}
